<?php

namespace Drupal\static_export_exporter_language_metadata\Plugin\static_export\Exporter\Custom;

use Drupal\static_export\Exporter\Output\Config\ExporterOutputConfigInterface;
use Drupal\static_export\Exporter\Type\Custom\CustomExporterPluginBase;

/**
 * Language metadata exporter.
 *
 * @StaticCustomExporter(
 *  id = "language-metadata",
 *  label = @Translation("Language metadata exporter"),
 *  description = @Translation("Exports language metadata"),
 * )
 */
class LanguageMetadataExporter extends CustomExporterPluginBase {

  /**
   * {@inheritdoc}
   */
  public function getExporterItem() {
    return 'language_metadata_exporter';
  }

  /**
   * {@inheritdoc}
   */
  public function getExporterItemId() {
    return 'language_metadata_exporter';
  }

  /**
   * {@inheritdoc}
   */
  public function getExporterItemLabel() {
    return "Language metadata exporter";
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  protected function getOutputDefinition(): ?ExporterOutputConfigInterface {
    $format = $this->configFactory->get('static_export.settings')->get('exportable_config.format');
    $outputFormatter = $this->outputFormatterManager->getInstance(['plugin_id' => $format]);
    $extension = $outputFormatter ? $outputFormatter->getPluginDefinition()['extension'] : $format;
    return $this->exporterOutputConfigFactory->create(
      'config',
      'languages',
      $extension
    )->setBaseDir('system');
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Exception
   */
  protected function calculateDataFromResolver() {
    // Reset config factory's internal cache so fresh data is retrieved.
    // Sometimes, when a commonly used configuration object is exported
    // (e.g.- system.site), it's already loaded and cached before this code
    // executes, leading to exporting stale data.
    $this->configFactory->reset('language.negotiation');
    $prefixes = $this->configFactory->get('language.negotiation')
      ->get('url.prefixes');
    $languages = [];

    foreach ($this->languageManager->getLanguages() as $language) {
      // Get the translated names of languages.
      $currentLangcode = $language->getId();
      $languageNames = [$currentLangcode => $language->getName()];
      $callable = function () use ($currentLangcode) {
        // Reset language entity config to get fresh data and translations.
        $this->configFactory->reset('language.entity.' . $currentLangcode);
        $subLanguage = $this->languageManager->getLanguage($currentLangcode);
        return $subLanguage ? $subLanguage->getName() : NULL;
      };
      foreach ($this->languageManager->getLanguages() as $subLanguage) {
        $subLangcode = $subLanguage->getId();
        $languageNames[$subLangcode] = $this->languageContext->executeInLanguageContext($callable, $subLangcode);
      }

      $languages[] = [
        'langcode' => $language->getId(),
        'name' => $languageNames,
        'isDefault' => $language->isDefault(),
        'prefix' => $prefixes[$language->getId()],
      ];
    }
    return $languages;
  }

}
