<?php

namespace Drupal\static_export\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Url;

/**
 * Base settings form for constrained exporters (entity, config, etc)
 */
abstract class ConstrainedExporterSettingsFormBase extends ConfigFormBase {

  /**
   * The route provider.
   *
   * @var \Drupal\Core\Routing\RouteProviderInterface
   */
  protected $routeProvider;

  /**
   * Get options for a tableselect form element.
   *
   * Get an array of options from a set of exporter definitions.
   *
   * @param array $definitions
   *   Set of exporter definitions.
   *
   * @return array
   *   Array of options for a tableselect form element.
   */
  public function getExporterDefinitionOptions(array $definitions): array {
    $options = NULL;
    foreach ($definitions as $pluginId => $pluginDefinition) {
      $option = [
        'id' => $pluginId,
        'name' => $pluginDefinition['label'],
        'description' => $pluginDefinition['description'],
      ];
      $pluginRoute = 'static_exporter_' . str_replace('-', '_', $pluginId) . '.settings';
      if (count($this->routeProvider->getRoutesByNames([$pluginRoute])) === 1) {
        $option['configuration']['data'] = [
          '#title' => $this->t('Edit configuration'),
          '#type' => 'link',
          '#url' => Url::fromRoute($pluginRoute),
        ];
      }
      else {
        $option['configuration'] = $this->t('No configuration available');
      }
      $options[$pluginId] = $option;
    }

    return $options;
  }

}
