<?php

namespace Drupal\static_suite\Command;

use Drupal\static_suite\Command\Result\CliCommandResultInterface;

/**
 * An interface for CLI commands.
 */
interface CliCommandInterface {

  /**
   * Returns the CLI command.
   *
   * @return string
   */
  public function getCmd(): string;

  /**
   * Returns the working directory for the command.
   *
   * @return string|null
   */
  public function getCwd(): ?string;

  /**
   * Returns the environment variables for the command.
   *
   * @return array|null
   */
  public function getEnv(): ?array;

  /**
   * Executes the command.
   *
   * @param string|null $stdIn
   *   Content that will be piped to the command.
   *
   * @return \Drupal\static_suite\Command\Result\CliCommandResultInterface
   *
   * @throws \Drupal\static_suite\StaticSuiteException
   *   If the command cannot be executed
   */
  public function execute(string $stdIn = NULL): CliCommandResultInterface;

}
